<?php
/**
 * The template for adding Featured Slider Options in Customizer
 *
 * @package Catch Themes
 * @subpackage Clean Business Pro
 * @since Clean Business 1.0
 */


// Featured Slider
$wp_customize->add_section( 'clean_business_featured_slider', array(
	'priority'      => 400,
	'title'			=> esc_html__( 'Featured Slider', 'clean-business-pro' ),
) );

$wp_customize->add_setting( 'featured_slider_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_option'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'featured_slider_option', array(
	'choices'   => clean_business_featured_slider_content_options(),
	'label'    	=> esc_html__( 'Enable Slider on', 'clean-business-pro' ),
	'priority'	=> '1.1',
	'section'  	=> 'clean_business_featured_slider',
	'settings' 	=> 'featured_slider_option',
	'type'    	=> 'select',
) );

$wp_customize->add_setting( 'featured_slider_transition_effect', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_transition_effect'],
	'sanitize_callback'	=> 'clean_business_sanitize_select',
) );

$wp_customize->add_control( 'featured_slider_transition_effect' , array(
	'active_callback'	=> 'clean_business_is_slider_active',
	'choices'  	=> clean_business_featured_slider_transition_effects(),
	'label'		=> esc_html__( 'Transition Effect', 'clean-business-pro' ),
	'priority'	=> '2',
	'section'  	=> 'clean_business_featured_slider',
	'settings' 	=> 'featured_slider_transition_effect',
	'type'	  	=> 'select',
	)
);

$wp_customize->add_setting( 'featured_slider_speed', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_speed'],
	'sanitize_callback'	=> 'clean_business_sanitize_number_range',
) );

$wp_customize->add_control( 'featured_slider_speed' , array(
	'active_callback'	=> 'clean_business_is_slider_active',
	'description'	=> esc_html__( 'seconds(s)', 'clean-business-pro' ),
	'input_attrs' => array(
        'min'   => 1,
        'style' => 'width: 60px;'
	),
	'label'    		=> esc_html__( 'Speed of the slideshow cycling', 'clean-business-pro' ),
	'priority'		=> '2.1.1',
	'section'  		=> 'clean_business_featured_slider',
	'settings' 		=> 'featured_slider_speed',
	'type'	   		=> 'number',
	)
);

$wp_customize->add_setting( 'featured_slider_type', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_type'],
	'sanitize_callback'	=> 'sanitize_key',
) );

$wp_customize->add_control( 'featured_slider_type', array(
	'active_callback'	=> 'clean_business_is_slider_active',
	'choices'  	=> clean_business_featured_slider_types(),
	'label'    	=> esc_html__( 'Select Slider Type', 'clean-business-pro' ),
	'priority'	=> '2.1.3',
	'section'  	=> 'clean_business_featured_slider',
	'settings' 	=> 'featured_slider_type',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'featured_slider_number', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_number'],
	'sanitize_callback'	=> 'clean_business_sanitize_number_range',
) );

$wp_customize->add_control( 'featured_slider_number' , array(
	'active_callback'	=> 'clean_business_is_demo_slider_inactive',
	'description'	=> esc_html__( 'Save and refresh the page if No. of Slides is changed (Max no of slides is 20)', 'clean-business-pro' ),
	'input_attrs' 	=> array(
        'style' => 'width: 45px;',
        'min'   => 0,
        'max'   => 20,
        'step'  => 1,
    	),
	'label'    		=> esc_html__( 'No of Slides', 'clean-business-pro' ),
	'priority'		=> '2.1.4',
	'section'  		=> 'clean_business_featured_slider',
	'settings' 		=> 'featured_slider_number',
	'type'	   		=> 'number',
	)
);

$wp_customize->add_setting( 'exclude_slider_post', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['exclude_slider_post'],
	'sanitize_callback'	=> 'clean_business_sanitize_checkbox',
) );

$wp_customize->add_control(  'exclude_slider_post', array(
	'active_callback'	=> 'clean_business_is_post_slider_active',
	'label'		=> esc_html__( 'Check to exclude Slider post from Homepage posts', 'clean-business-pro' ),
	'priority'	=> '2.1.4.1',
	'section'   => 'clean_business_featured_slider',
	'settings'  => 'exclude_slider_post',
	'type'		=> 'checkbox',
) );

$wp_customize->add_setting( 'featured_slider_select_category', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'clean_business_sanitize_category_list',
) );

$wp_customize->add_control( new clean_business_customize_dropdown_categories_control( $wp_customize, 'clean_business_featured_slider_select_category', array(
    'active_callback'	=> 'clean_business_is_category_slider_active',
    'label'   	=> esc_html__('Select Categories', 'clean-business-pro' ),
    'name' 		=> 'featured_slider_select_category',
	'priority'	=> '10',
    'section'  	=> 'clean_business_featured_slider',
    'settings' 	=> 'featured_slider_select_category',
    'type'     	=> 'dropdown-categories',
) ) );

$featured_slider_number = apply_filters( 'clean_business_get_option', 'featured_slider_number' );

//loop for featured post sliders
$priority	=	'11';
for ( $i=1; $i <=  $featured_slider_number ; $i++ ) {
	$wp_customize->add_setting( 'featured_slider_post_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'clean_business_sanitize_page',
	) );

	$wp_customize->add_control( 'featured_slider_post_'. $i, array(
		'active_callback'	=> 'clean_business_is_post_slider_active',
		'input_attrs' => array(
    		'style' => 'width: 80px;'
		),
		'label'    	=> esc_html__( 'Featured Post', 'clean-business-pro' ) . ' # ' . $i ,
		'priority'	=>  '3' . $i,
		'section'  	=> 'clean_business_featured_slider',
		'settings' 	=> 'featured_slider_post_'. $i,
		'type'	   	=> 'text',
		)
	);

	$wp_customize->add_setting( 'featured_slider_page_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'clean_business_sanitize_page',
	) );

	$wp_customize->add_control( 'featured_slider_page_'. $i, array(
		'active_callback'	=> 'clean_business_is_page_slider_active',
		'label'    	=> esc_html__( 'Featured Page', 'clean-business-pro' ) . ' # ' . $i ,
		'priority'	=> '4' . $i,
		'section'  	=> 'clean_business_featured_slider',
		'settings' 	=> 'featured_slider_page_'. $i,
		'type'	   	=> 'dropdown-pages',
	) );


	if( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
		$priority++;

	$wp_customize->add_setting( 'featured_slider_note_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new clean_business_note_control( $wp_customize, 'featured_slider_note_'. $i, array(
        'active_callback'	=> 'clean_business_is_image_slider_active',
        'label'		=> esc_html__( 'Featured Slide #', 'clean-business-pro' ) . $i,
		'priority'	=> $priority . '.' . $i,
        'section'  	=> 'clean_business_featured_slider',
        'settings'	=> 'featured_slider_note_'. $i,
        'type'     	=> 'description',
		) ) );

	$wp_customize->add_setting( 'featured_slider_image_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'clean_business_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'featured_slider_image_'. $i , array(
        'active_callback'	=> 'clean_business_is_image_slider_active',
		'label'		=> esc_html__( 'Image', 'clean-business-pro' ),
		'priority'	=> $priority . '.' . $i .$i,
		'section'   => 'clean_business_featured_slider',
        'settings'  => 'featured_slider_image_'. $i,
	) ) );

	$wp_customize->add_setting( 'featured_link_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'featured_link_'. $i, array(
        'active_callback'	=> 'clean_business_is_image_slider_active',
		'label'		=> esc_html__( 'Link', 'clean-business-pro' ),
        'priority'	=> $priority . '.' .$i . $i  . $i,
		'section'   => 'clean_business_featured_slider',
        'settings'  => 'featured_link_'. $i,
	) );

	$wp_customize->add_setting( 'featured_button_text_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'featured_button_text_'. $i, array(
        'active_callback'	=> 'clean_business_is_image_slider_active',
		'label'		=> esc_html__( 'Button Text', 'clean-business-pro' ),
        'priority'	=> $priority . '.' .$i . $i  . $i,
		'section'   => 'clean_business_featured_slider',
        'settings'  => 'featured_button_text_'. $i,
	) );

	$wp_customize->add_setting( 'featured_target_'. $i, array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'clean_business_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'featured_target_'. $i, array(
        'active_callback'	=> 'clean_business_is_image_slider_active',
		'label'		=> esc_html__( 'Check to Open Link in New Window/Tab', 'clean-business-pro' ),
        'priority'	=> $priority . '.' .$i  .$i  . $i . $i,
		'section'   => 'clean_business_featured_slider',
        'settings'  => 'featured_target_'. $i,
		'type'		=> 'checkbox',
    ) );

    $wp_customize->add_setting( 'featured_title_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'featured_title_'. $i, array(
        'active_callback'	=> 'clean_business_is_image_slider_active',
		'label'		=> esc_html__( 'Title', 'clean-business-pro' ),
        'priority'	=> $priority . '.' .$i .  $i.  $i .$i . $i,
		'section'   => 'clean_business_featured_slider',
        'settings'  => 'featured_title_'. $i,
		'type'		=> 'text',
    ) );

    $wp_customize->add_setting( 'featured_content_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'wp_kses_post', //Only allow html tags allowed in posts
	) );

	$wp_customize->add_control( 'featured_content_'. $i, array(
        'active_callback'	=> 'clean_business_is_image_slider_active',
		'label'		=> esc_html__( 'Content', 'clean-business-pro' ),
        'priority'	=> $priority . '.' . $i . $i .  $i . $i . $i . $i,
		'section'   => 'clean_business_featured_slider',
        'settings'  => 'featured_content_'. $i,
		'type'		=> 'textarea',
    ) );
}
// Featured Slider End