<?php
/**
 * The template for displaying Social Icons
 *
 * @package Catch Themes
 * @subpackage Clean Business Pro
 * @since Clean Business 1.0
 */

if ( ! function_exists( 'clean_business_get_social_icons' ) ) :
/**
 * Generate social icons.
 *
 * @since Clean Business 1.0
 */
function clean_business_get_social_icons(){
	if( ( !$output = get_transient( 'clean_business_social_icons' ) ) ) {
		$output	= '';

		//Pre defined Social Icons Link Start
		$pre_def_social_icons 	=	clean_business_get_social_icons_list();

		foreach ( $pre_def_social_icons as $key => $item ) {
			$social_icon = apply_filters( 'clean_business_get_option', $key );

			if( $social_icon && '' != $social_icon ) {
				$value = $social_icon;

				if ( 'email_link' == $key  ) {
					$output .= '<a class="fa fa-'. esc_attr( $item['class'] ) .'" target="_blank" title="'. esc_attr__( 'Email', 'clean-business-pro') . '" href="mailto:'. antispambot( sanitize_email( $value ) ) .'"><span class="screen-reader-text">'. __( 'Email', 'clean-business-pro') . '</span> </a>';
				}
				else if ( 'skype_link' == $key  ) {
					$output .= '<a class="fa fa-'. esc_attr( $item['class'] ) .'" target="_blank" title="'. esc_attr( $item['label'] ) . '" href="'. esc_attr( $value ) .'"><span class="screen-reader-text">'. esc_attr( $item['label'] ). '</span> </a>';
				}
				else if ( 'phone_link' == $key || 'handset_link' == $key ) {
					$output .= '<a class="fa fa-'. esc_attr( $item['class'] ) .'" target="_blank" title="'. esc_attr( $item['label'] ) . '" href="tel:' . preg_replace( '/\s+/', '', esc_attr( $value ) ) . '"><span class="screen-reader-text">'. esc_attr( $item['label'] ) . '</span> </a>';
				}
				else {
					$output .= '<a class="fa fa-'. esc_attr( $item['class'] ) .'" target="_blank" title="'. esc_attr( $item['label'] ) .'" href="'. esc_url( $value ) .'"><span class="screen-reader-text">'. esc_attr( $item['label'] ) .'</span> </a>';
				}
			}
		}
		//Pre defined Social Icons Link End

		//Custom Social Icons Link Start
		$custom_social_icons = apply_filters( 'clean_business_get_option', 'custom_social_icons' );

		for( $i = 1; $i <= $custom_social_icons ; $i++ ) {
			$has_hover 		= '';
			$image_hover 	= '';

			$image = apply_filters( 'clean_business_get_option', 'custom_social_icon_image_'. $i );

			if ( $image ) {
				if ( ! empty( $options['custom_social_icon_image_hover_'. $i] ) ) {
					$image_hover = apply_filters( 'clean_business_get_option', 'custom_social_icon_image_hover_'. $i );
					$has_hover = " has-hover";
				}

				//Checking Link
				$link = apply_filters( 'clean_business_get_option', 'custom_social_icon_link_'. $i );
				if ( !$link ) {
					$link = '#';
				}

				//Checking Title
				$title = apply_filters( 'clean_business_get_option', 'custom_social_icon_title_'. $i );

				//Custom Social Icons
				$output .= '<a id="custom-icon-'. $i .'" class="custom-icon' . $has_hover . '" target="_blank" title="' . esc_attr( $title ) . '" href="' . esc_url( $link ) . '">
					<img  alt="' . esc_attr( $title ) . '" class ="icon-static" src="' . esc_url( $image ) . '" />';

					if (isset ( $image_hover ) && '' != $image_hover ) {
					$output .= '<img  alt="' . esc_attr( $title ) . '" class ="icon-hover" src="' . esc_url( $image_hover ) . '" />';
				}
				$output .= '</a>';
			}
		}
		//Custom Social Icons Link End
		set_transient( 'clean_business_social_icons', $output, 86940 );
	}

	return $output;
} // clean_business_get_social_icons
endif;
