<?php
/**
 * The template for adding Custom Sidebars and Widgets
 *
 * @package Catch Themes
 * @subpackage Clean Business
 * @since Clean Business Pro 1.0
 */

/**
 * Register widgetized area
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_widgets_init() {
	//Primary Sidebar
	register_sidebar( array(
		'name'          => esc_html__( 'Primary Sidebar', 'clean-business-pro' ),
		'id'            => 'primary-sidebar',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	$footer_sidebar_number = 4; //Number of footer sidebars

	for( $i=1; $i <= $footer_sidebar_number; $i++ ) {
		register_sidebar( array(
			'name'          => sprintf( esc_html__( 'Footer Area %d', 'clean-business-pro' ), $i ),
			'id'            => sprintf( 'footer-%d', $i ),
			'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
			'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
			'description'	=> sprintf( esc_html__( 'Footer %d widget area.', 'clean-business-pro' ), $i ),
		) );
	}

	//Sidebar Before Content
	register_sidebar( array(
		'name'          => __( 'Before Content', 'clean-business-pro' ),
		'id'            => 'before-content',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
		'description'	=> __( 'This is the Before Content widget area. It typically appears on the before the Content.', 'clean-business-pro' ),
	) );

	//Sidebar After Content
	register_sidebar( array(
		'name'          => __( 'After Content', 'clean-business-pro' ),
		'id'            => 'after-content',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
		'description'	=> __( 'This is the After Content widget area. It typically appears after the Content.', 'clean-business-pro' ),
	) );

	//Featured Widget Content
	register_sidebar( array(
		'name'          => esc_html__( 'Featured Widget Content', 'clean-business-pro' ),
		'id'            => 'featured-widget-content',
		'before_widget' => '<section id="%1$s" class="hentry widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
		'description'	=> esc_html__( 'This is the Featured Widget Content. Enable it by going to Appearance => Customize => Featured Widget Content Options => Enable Featured content Widget Content on', 'clean-business-pro' ),
	) );

	//Promotion Headline Left
	register_sidebar( array(
		'name'          => esc_html__( 'Promotion Headline Left', 'clean-business-pro' ),
		'id'            => 'promotion-headline-left',
		'before_widget' => '<div id="%1$s" class="section left">',
		'after_widget'  => '</div><!-- .section .left -->',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		'description'	=> esc_html__( 'This is the Promotion Headline Left. Enable it by going to Appearance => Customize => Theme Options => Promotion Headline Options.', 'clean-business-pro' ),
	) );

	//Promotion Headline Right
	register_sidebar( array(
		'name'          => esc_html__( 'Promotion Headline Right', 'clean-business-pro' ),
		'id'            => 'promotion-headline-right',
		'before_widget' => '<div id="%1$s" class="section right">',
		'after_widget'  => '</div><!-- .section .right -->',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		'description'	=> esc_html__( 'This is the Promotion Headline Right. Enable it by going to Appearance => Customize => Theme Options => Promotion Headline Options.', 'clean-business-pro' ),
	) );

	// Registering 404 Error Page Content
	register_sidebar( array(
		'name'					=> esc_html__( '404 Page Not Found Content', 'clean-business-pro' ),
		'id' 					=> 'sidebar-notfound',
		'description'			=> esc_html__( 'Replaces the default 404 Page Not Found Content', 'clean-business-pro' ),
		'before_widget'			=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'			=> '</aside>',
		'before_title'			=> '<h2 class="widget-title">',
		'after_title'			=> '</h2>',
	) );

	if ( class_exists( 'woocommerce' ) ) {
		//Optional Primary Sidebar for Shop
		register_sidebar( array(
			'name' 				=> esc_html__( 'WooCommerce Primary Sidebar', 'clean-business-pro' ),
			'id' 				=> 'sidebar-optional-woocommmerce',
			'description'		=> esc_html__( 'This is Optional Primary Sidebar for WooCommerce', 'clean-business-pro' ),
			'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
			'after_widget' 		=> "</aside>",
			'before_title' 		=> '<h3 class="widget-title">',
			'after_title' 		=> '</h3>'
		) );
	}

	//Optional Sidebar for Hompeage instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Homepage Sidebar', 'clean-business-pro' ),
		'id' 				=> 'sidebar-optional-homepage',
		'description'		=> esc_html__( 'This is Optional Sidebar for Homepage', 'clean-business-pro' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar for Archive instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Archive Sidebar', 'clean-business-pro' ),
		'id' 				=> 'sidebar-optional-archive',
		'description'		=> esc_html__( 'This is Optional Sidebar for Archive', 'clean-business-pro' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar for Page instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Page Sidebar', 'clean-business-pro' ),
		'id' 				=> 'sidebar-optional-page',
		'description'		=> esc_html__( 'This is Optional Sidebar for Page', 'clean-business-pro' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar for Post instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Post Sidebar', 'clean-business-pro' ),
		'id' 				=> 'sidebar-optional-post',
		'description'		=> esc_html__( 'This is Optional Sidebar for Post', 'clean-business-pro' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar one for page and post
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Sidebar One', 'clean-business-pro' ),
		'id' 				=> 'sidebar-optional-one',
		'description'		=> esc_html__( 'This is Optional Sidebar One', 'clean-business-pro' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar two for page and post
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Sidebar Two', 'clean-business-pro' ),
		'id' 				=> 'sidebar-optional-two',
		'description'		=> esc_html__( 'This is Optional Sidebar Two', 'clean-business-pro' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar Three for page and post
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Sidebar Three', 'clean-business-pro' ),
		'id' 				=> 'sidebar-optional-three',
		'description'		=> esc_html__( 'This is Optional Sidebar Three', 'clean-business-pro' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );
}
add_action( 'widgets_init', 'clean_business_widgets_init' );

/**
 * Loads up Necessary JS Scripts for widgets
 *
 * @since Clean Business Pro 1.0
 */
function clean_business_widgets_scripts( $hook) {
	if ( 'widgets.php' == $hook ) {
		wp_enqueue_style( 'automobile-widgets-styles', get_template_directory_uri() . '/css/widgets.css' );
	}
}
add_action( 'admin_enqueue_scripts', 'clean_business_widgets_scripts' );

// Load About Widget
include get_template_directory() . '/inc/widgets/about.php';

// Load Advertisement Code Widget
include get_template_directory() . '/inc/widgets/advertisement-code.php';

// Load Advertisement Image Widget
include get_template_directory() . '/inc/widgets/advertisement-image.php';

// Load Featured Embed Widget
include get_template_directory() . '/inc/widgets/featured-embed.php';

// Load Featured Image Widget
include get_template_directory() . '/inc/widgets/featured-image.php';

// Load Featured Page Widget
include get_template_directory() . '/inc/widgets/featured-page.php';

// Load Featured Post Widget
include get_template_directory() . '/inc/widgets/featured-posts.php';

// Load Gallery Image Widget
include get_template_directory() . '/inc/widgets/gallery-image.php';

// Load Gallery Page Widget
include get_template_directory() . '/inc/widgets/gallery-page.php';

// Load Gallery Post Widget
include get_template_directory() . '/inc/widgets/gallery-posts.php';

// Load Instagram Widget
include get_template_directory() . '/inc/widgets/instagram.php';

// Load Newsletter Widget
include get_template_directory() . '/inc/widgets/newsletter.php';

// Load Social Icon Widget
include get_template_directory() . '/inc/widgets/social-icons.php';

// Load Newsletter Widget
include get_template_directory() . '/inc/widgets/tag-cloud.php';


if ( ! function_exists( 'clean_business_truncate_phrase' ) ) :
	/**
	 * Return a phrase shortened in length to a maximum number of characters.
	 *
	 * Result will be truncated at the last white space in the original string. In this function the word separator is a
	 * single space. Other white space characters (like newlines and tabs) are ignored.
	 *
	 * If the first `$max_characters` of the string does not contain a space character, an empty string will be returned.
	 *
	 * @since NepalBuzz 1.0
	 *
	 * @param string $text            A string to be shortened.
	 * @param integer $max_characters The maximum number of characters to return.
	 *
	 * @return string Truncated string
	 */
	function clean_business_truncate_phrase( $text, $max_characters ) {

		$text = trim( $text );

		if ( mb_strlen( $text ) > $max_characters ) {
			//* Truncate $text to $max_characters + 1
			$text = mb_substr( $text, 0, $max_characters + 1 );

			//* Truncate to the last space in the truncated string
			$text = trim( mb_substr( $text, 0, mb_strrpos( $text, ' ' ) ) );
		}

		return $text;
	}
endif; //clean_business_truncate_phrase


if ( ! function_exists( 'clean_business_get_the_content_limit' ) ) :
	/**
	 * Return content stripped down and limited content.
	 *
	 * Strips out tags and shortcodes, limits the output to `$max_char` characters, and appends an ellipsis and more link to the end.
	 *
	 * @since NepalBuzz 1.0
	 *
	 * @param integer $max_characters The maximum number of characters to return.
	 * @param string  $more_link_text Optional. Text of the more link. Default is "(more...)".
	 * @param bool    $stripteaser    Optional. Strip teaser content before the more text. Default is false.
	 *
	 * @return string Limited content.
	 */
	function clean_business_get_the_content_limit( $max_characters, $more_link_text = '(more...)', $stripteaser = false ) {

		$content = get_the_content( '', $stripteaser );

		//* Strip tags and shortcodes so the content truncation count is done correctly
		$content = strip_tags( strip_shortcodes( $content ), apply_filters( 'get_the_content_limit_allowedtags', '<script>,<style>' ) );

		//* Remove inline styles / scripts
		$content = trim( preg_replace( '#<(s(cript|tyle)).*?</\1>#si', '', $content ) );

		//* Truncate $content to $max_char
		$content = clean_business_truncate_phrase( $content, $max_characters );

		//* More link?
		if ( $more_link_text ) {
			$link   = apply_filters( 'get_the_content_more_link', sprintf( '<span class="more-button"><a href="%s" class="more-link">%s</a></span>', esc_url( get_permalink() ), $more_link_text ), $more_link_text );
			$output = sprintf( '<p>%s %s</p>', $content, $link );
		} else {
			$output = sprintf( '<p>%s</p>', $content );
			$link = '';
		}

		return apply_filters( 'clean_business_get_the_content_limit', $output, $content, $link, $max_characters );

	}
endif; //clean_business_get_the_content_limit
